==> flac2all-4.1.tar.gz: flac2all-4.1/setup.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
# vim: ts=4 expandtab ai
#
# File Created: Tue 10 Jan 00:31:22 GMT 2017
# Copyright 2017
#
# Licensced under the GPLv3
#
#  =============================================================|

from setuptools import setup, find_packages
from os import path

here = path.abspath(path.dirname(__file__))

long_description = '''
Started in 2003 as a flac to ogg vorbis converter, flac2All has grown into a multithreaded script that will convert your collection of FLAC files into various other formats (currently mp3,ogg vorbis,opus, flac and acc), complete with any tags that the source file had. Designed to be extended with new formats easily as time goes on, it is a utility for people with with large FLAC collections who want a way to convert multiple files in parallel.

Tested on Linux and FreeBSD, let me know how it works on other Unix OS'es.
'''

with open("version", 'r') as fd:
    vers = fd.read()
    vers = vers.strip()

setup(
    name="flac2all",
    version=vers,
    packages=["flac2all_pkg"],
    # metadata for upload to PyPI
    author="ZivaVatra",
    author_email="zv@ziva-vatra.com",
    description='''
Multi process, multi codec audio converter with tagging support
''',
    license="GPLv3",
    url="https://github.com/ZivaVatra/flac2all",
    # From https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Console',
        'Intended Audience :: End Users/Desktop',
        'License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)',
        'Natural Language :: English',
        'Operating System :: POSIX :: BSD',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Topic :: Multimedia :: Sound/Audio :: Conversion',
    ],
    keywords='multithread, multiprocess, batch, flac, converter, mp3, vorbis,\
opus, aac, lame, music, audio',

    entry_points={
        'console_scripts': [
            'flac2all = flac2all_pkg.__init__:main',
        ],
    }
)

==> flac2all-4.3.tar.gz: flac2all-4.3/setup.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
# vim: ts=4 expandtab ai
#
# File Created: Tue 10 Jan 00:31:22 GMT 2017
# Copyright 2017
#
# Licensced under the GPLv3
#
#  =============================================================|

from setuptools import setup, find_packages
from os import path

here = path.abspath(path.dirname(__file__))

with open("./flac2all_pkg/version", 'r') as fd:
    vers = fd.read()
    vers = vers.strip()

setup(
    name="flac2all",
    version=vers,
    packages=["flac2all_pkg"],
    # metadata for upload to PyPI
    author="ZivaVatra",
    author_email="info@ziva-vatra.com",
    description="Multi process, multi codec audio converter with tagging support",
	long_description='''
Started in 2003 as a flac to ogg vorbis converter, flac2All has grown into a multithreaded script that will convert your collection of FLAC files into various other formats (currently mp3,ogg vorbis,opus, flac and acc), complete with any tags that the source file had. Designed to be extended with new formats easily as time goes on, it is a utility for people with with large FLAC collections who want a way to convert multiple files in parallel.

Tested on Linux and FreeBSD, let me know how it works on other Unix OS'es.
''',
	long_description_content_type="text/plain",
    license="GPLv3",
    url="https://github.com/ZivaVatra/flac2all",
    # From https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Console',
        'Intended Audience :: End Users/Desktop',
        'License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)',
        'Natural Language :: English',
        'Operating System :: POSIX :: BSD',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Topic :: Multimedia :: Sound/Audio :: Conversion',
    ],
    keywords='multithread, multiprocess, batch, flac, converter, mp3, vorbis,\
opus, aac, lame, music, audio',

    entry_points={
        'console_scripts': [
            'flac2all = flac2all_pkg.__init__:main',
        ],
    }
)
